Documentation
¶
Overview ¶
Package vxlan helps with creating transient VXLAN network interfaces for testing purposes. It leverages the Ginkgo testing framework and matching (erm, sic!) Gomega matchers.
These VXLAN network interfaces are transient because they automatically get removed at the end of the a test (spec, block/group, suite, et cetera) using Ginkgo's DeferCleanup.
Index ¶
Constants ¶
const VxlanPrefix = "vxl-"
VxlanPrefix is the name prefix used for transient VXLAN network interfaces.
Variables ¶
This section is empty.
Functions ¶
func NewTransient ¶
NewTransient creates and returns a new (and transient) VXLAN network interface attached to the specified underlay network interface (which must be a hardware network interface, including the dummy kind). NewTransient automatically defers proper automatic removal of the VXLAN network interface.
Types ¶
type Opt ¶
Opt is a configuration option when creating a new VXLAN network interface.
func InNamespace ¶
InNamespace configures a VXLAN network interface to be created in the network namespace referenced by fdref, instead of creating it in the current network namespace.
func WithDestinationPort ¶
WithDestinationPort configures the UDP destination port for communicating to the remote VXLAN tunnel endpoint.
func WithLinkNamespace ¶
WithLinkNamespace specifies the “reference” or “link” network namespace other than the current network namespace when creating a new network interface.
func WithSourcePorts ¶
WithSourcePorts configures the range of port numbers to use as UDP source ports when communicating to the remote VXLAN tunnel endpoint.